REORG: polling: rename the cache allocation functions

- alloc_spec_entry() becomes fd_alloc_cache_entry()
- release_spec_entry() becomes fd_release_cache_entry()
diff --git a/src/ev_poll.c b/src/ev_poll.c
index 6d550a6..eff9007 100644
--- a/src/ev_poll.c
+++ b/src/ev_poll.c
@@ -93,13 +93,12 @@
 				/* This fd doesn't use any active entry anymore, we can
 				 * kill its entry.
 				 */
-				release_spec_entry(fd);
+				fd_release_cache_entry(fd);
 			}
 			else if ((en & ~eo) & FD_EV_ACTIVE_RW) {
-				/* we need a new spec entry now */
-				alloc_spec_entry(fd);
+				/* we need a new cache entry now */
+				fd_alloc_cache_entry(fd);
 			}
-
 		}
 		fdtab[fd].updated = 0;
 		fdtab[fd].new = 0;